@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2010 Jakub Wilk <jwilk@jwilk.net>
-// Copyright (C) 2017-2019 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2017-2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2017 Jean Ghali <jghali@libertysurf.fr>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
@@ -50,7 +50,7 @@ struct UnicodeMapExt {
 
 //------------------------------------------------------------------------
 
-UnicodeMap *UnicodeMap::parse(GooString *encodingNameA) {
+UnicodeMap *UnicodeMap::parse(const std::string &encodingNameA) {
   FILE *f;
   UnicodeMap *map;
   UnicodeMapRange *range;
@@ -63,12 +63,12 @@ UnicodeMap *UnicodeMap::parse(GooString *encodingNameA) {
 
   if (!(f = globalParams->getUnicodeMapFile(encodingNameA))) {
     error(errSyntaxError, -1,
-	  "Couldn't find unicodeMap file for the '{0:t}' encoding",
-	  encodingNameA);
+	  "Couldn't find unicodeMap file for the '{0:s}' encoding",
+	  encodingNameA.c_str());
     return nullptr;
   }
 
-  map = new UnicodeMap(encodingNameA->copy());
+  map = new UnicodeMap(encodingNameA);
 
   size = 8;
   UnicodeMapRange *customRanges = (UnicodeMapRange *)gmallocn(size, sizeof(UnicodeMapRange));
@@ -112,13 +112,13 @@ UnicodeMap *UnicodeMap::parse(GooString *encodingNameA) {
 	++map->eMapsLen;
       } else {
 	error(errSyntaxError, -1,
-	      "Bad line ({0:d}) in unicodeMap file for the '{1:t}' encoding",
-	      line, encodingNameA);
+	      "Bad line ({0:d}) in unicodeMap file for the '{1:s}' encoding",
+	      line, encodingNameA.c_str());
       }
     } else {
       error(errSyntaxError, -1,
-	    "Bad line ({0:d}) in unicodeMap file for the '{1:t}' encoding",
-	    line, encodingNameA);
+	    "Bad line ({0:d}) in unicodeMap file for the '{1:s}' encoding",
+	    line, encodingNameA.c_str());
     }
     ++line;
   }
@@ -129,7 +129,7 @@ UnicodeMap *UnicodeMap::parse(GooString *encodingNameA) {
   return map;
 }
 
-UnicodeMap::UnicodeMap(GooString *encodingNameA) {
+UnicodeMap::UnicodeMap(const std::string &encodingNameA) {
   encodingName = encodingNameA;
   unicodeOut = false;
   kind = unicodeMapUser;
@@ -137,34 +137,30 @@ UnicodeMap::UnicodeMap(GooString *encodingNameA) {
   len = 0;
   eMaps = nullptr;
   eMapsLen = 0;
-  refCnt = 1;
 }
 
 UnicodeMap::UnicodeMap(const char *encodingNameA, bool unicodeOutA,
 		       const UnicodeMapRange *rangesA, int lenA) {
-  encodingName = new GooString(encodingNameA);
+  encodingName = encodingNameA;
   unicodeOut = unicodeOutA;
   kind = unicodeMapResident;
   ranges = rangesA;
   len = lenA;
   eMaps = nullptr;
   eMapsLen = 0;
-  refCnt = 1;
 }
 
 UnicodeMap::UnicodeMap(const char *encodingNameA, bool unicodeOutA,
 		       UnicodeMapFunc funcA) {
-  encodingName = new GooString(encodingNameA);
+  encodingName = encodingNameA;
   unicodeOut = unicodeOutA;
   kind = unicodeMapFunc;
   func = funcA;
   eMaps = nullptr;
   eMapsLen = 0;
-  refCnt = 1;
 }
 
 UnicodeMap::~UnicodeMap() {
-  delete encodingName;
   if (kind == unicodeMapUser && ranges) {
     gfree(const_cast<UnicodeMapRange *>(ranges));
   }
@@ -174,13 +170,12 @@ UnicodeMap::~UnicodeMap() {
 }
 
 UnicodeMap::UnicodeMap(UnicodeMap &&other) noexcept
-  : encodingName{other.encodingName}
+  : encodingName{std::move(other.encodingName)}
   , kind{other.kind}
   , unicodeOut{other.unicodeOut}
   , len{other.len}
   , eMaps{other.eMaps}
   , eMapsLen{other.eMapsLen}
-  , refCnt{1}
 {
   switch (kind) {
   case unicodeMapUser:
@@ -192,7 +187,6 @@ UnicodeMap::UnicodeMap(UnicodeMap &&other) noexcept
     func = other.func;
     break;
   }
-  other.encodingName = nullptr;
   other.eMaps = nullptr;
 }
 
@@ -247,18 +241,8 @@ void UnicodeMap::swap(UnicodeMap &other) noexcept
   swap(eMapsLen, other.eMapsLen);
 }
 
-void UnicodeMap::incRefCnt() {
-  refCnt.fetch_add(1);
-}
-
-void UnicodeMap::decRefCnt() {
-  if (refCnt.fetch_sub(1) == 1) {
-    delete this;
-  }
-}
-
-bool UnicodeMap::match(const GooString *encodingNameA) const {
-  return !encodingName->cmp(encodingNameA);
+bool UnicodeMap::match(const std::string &encodingNameA) const {
+  return encodingName == encodingNameA;
 }
 
 int UnicodeMap::mapUnicode(Unicode u, char *buf, int bufSize) const {
@@ -311,52 +295,23 @@ int UnicodeMap::mapUnicode(Unicode u, char *buf, int bufSize) const {
 //------------------------------------------------------------------------
 
 UnicodeMapCache::UnicodeMapCache() {
-  int i;
-
-  for (i = 0; i < unicodeMapCacheSize; ++i) {
-    cache[i] = nullptr;
-  }
 }
 
 UnicodeMapCache::~UnicodeMapCache() {
-  int i;
-
-  for (i = 0; i < unicodeMapCacheSize; ++i) {
-    if (cache[i]) {
-      cache[i]->decRefCnt();
-    }
+  for (UnicodeMap *map : cache) {
+    delete map;
   }
 }
 
-UnicodeMap *UnicodeMapCache::getUnicodeMap(GooString *encodingName) {
-  UnicodeMap *map;
-  int i, j;
-
-  if (cache[0] && cache[0]->match(encodingName)) {
-    cache[0]->incRefCnt();
-    return cache[0];
-  }
-  for (i = 1; i < unicodeMapCacheSize; ++i) {
-    if (cache[i] && cache[i]->match(encodingName)) {
-      map = cache[i];
-      for (j = i; j >= 1; --j) {
-	cache[j] = cache[j - 1];
-      }
-      cache[0] = map;
-      map->incRefCnt();
+const UnicodeMap *UnicodeMapCache::getUnicodeMap(const std::string &encodingName) {
+  for (UnicodeMap *map : cache) {
+    if (map->match(encodingName)) {
       return map;
     }
   }
-  if ((map = UnicodeMap::parse(encodingName))) {
-    if (cache[unicodeMapCacheSize - 1]) {
-      cache[unicodeMapCacheSize - 1]->decRefCnt();
-    }
-    for (j = unicodeMapCacheSize - 1; j >= 1; --j) {
-      cache[j] = cache[j - 1];
-    }
-    cache[0] = map;
-    map->incRefCnt();
-    return map;
+  UnicodeMap *map = UnicodeMap::parse(encodingName);
+  if (map) {
+    cache.emplace_back(map);
   }
-  return nullptr;
+  return map;
 }
